==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/pl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Address book name" : "Nazwa książki adresowej",
    "Import" : "Importuj",
    "The selected image is too big (max 1MB)" : "Wybrany plik jest zbyt duży (maks. 1 MB)",
    "No contacts in here" : "Nie ma tu żadnych kontaktów",
    "Name" : "Nazwa",
    "Organization" : "Organizacja",
    "Title" : "Tytuł",
    "Add field ..." : "Dodaj pole ...",
    "No search result for {query}" : "Brak wyników wyszukiwania dla zapytania {query}",
    "Post office box" : "Skrytka Pocztowa",
    "Postal code" : "Kod pocztowy",
    "City" : "Miasto",
    "State or province" : "Województwo ",
    "Country" : "Kraj",
    "Address" : "Adres",
    "(new group)" : "Nowa grupa",
    "Last name" : "Nazwisko",
    "First name" : "Imię",
    "Additional names" : "Dodatkowe nazwy",
    "All contacts" : "Wszystkie kontakty",
    "Not grouped" : "Nie zgrupowane",
    "New contact" : "Nowy kontakt",
    "{addressbook} shared by {owner}" : "Książka {addressbook} udostępniona przez {owner}",
    "No contacts in file. Only VCard files are allowed." : "Brak kontaktów w pliku. Dozwolone są tylko pliki VCard.",
    "Nickname" : "Nazwa",
    "Detailed name" : "Szczegółowa nazwa",
    "Notes" : "Notatki",
    "Website" : "Strona www",
    "Home" : "Strona główna",
    "Work" : "Zawodowe",
    "Other" : "Inne",
    "Groups" : "Grupy",
    "Birthday" : "Urodziny",
    "Email" : "Email",
    "Instant messaging" : "Szybkie wiadomości",
    "Phone" : "Telefon",
    "Mobile" : "Komórka",
    "Fax" : "Faks",
    "Fax home" : "Faks domowy",
    "Fax work" : "Fakx pracowy",
    "Pager" : "Pager",
    "Voice" : "Połączenie głosowe",
    "Social network" : "Siec społecznościowa",
    "Settings" : "Ustawienia"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/pl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Download" : "Pobierz",
    "Share with users or groups" : "Współdziel z grupami bądź użytkownikami",
    "Delete" : "Usuń",
    "can edit" : "może edytować",
    "Address book name" : "Nazwa książki adresowej",
    "Import" : "Importuj",
    "The selected image is too big (max 1MB)" : "Wybrany plik jest zbyt duży (maks. 1 MB)",
    "No contacts in here" : "Nie ma tu żadnych kontaktów",
    "Name" : "Nazwa",
    "Organization" : "Organizacja",
    "Title" : "Tytuł",
    "Add field ..." : "Dodaj pole ...",
    "No search result for {query}" : "Brak wyników wyszukiwania dla zapytania {query}",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontaktów","%n kontaktów"],
    "Post office box" : "Skrytka Pocztowa",
    "Postal code" : "Kod pocztowy",
    "City" : "Miasto",
    "State or province" : "Województwo ",
    "Country" : "Kraj",
    "Address" : "Adres",
    "(new group)" : "Nowa grupa",
    "Last name" : "Nazwisko",
    "First name" : "Imię",
    "Additional names" : "Dodatkowe nazwy",
    "Prefix" : "Przedrostek",
    "Suffix" : "Przyrostek",
    "All contacts" : "Wszystkie kontakty",
    "Not grouped" : "Nie zgrupowane",
    "New contact" : "Nowy kontakt",
    "{addressbook} shared by {owner}" : "Książka {addressbook} udostępniona przez {owner}",
    "Contact could not be created." : "Nie można utworzyć kontaktu",
    "No contacts in file. Only VCard files are allowed." : "Brak kontaktów w pliku. Dozwolone są tylko pliki VCard.",
    "Nickname" : "Nazwa",
    "Detailed name" : "Szczegółowa nazwa",
    "Notes" : "Notatki",
    "Website" : "Strona www",
    "Federated Cloud ID" : "ID chmury stowarzyszonej",
    "Home" : "Strona główna",
    "Work" : "Zawodowe",
    "Other" : "Inne",
    "Groups" : "Grupy",
    "Birthday" : "Urodziny",
    "Anniversary" : "Rocznica",
    "Date of death" : "Data śmierci",
    "Email" : "Email",
    "Instant messaging" : "Szybkie wiadomości",
    "Phone" : "Telefon",
    "Mobile" : "Komórka",
    "Fax" : "Faks",
    "Fax home" : "Faks domowy",
    "Fax work" : "Fakx pracowy",
    "Pager" : "Pager",
    "Voice" : "Połączenie głosowe",
    "Social network" : "Siec społecznościowa",
    "Settings" : "Ustawienia"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
